@@ -327,7 +327,7 @@ class TC_10_Thunderbird(SplitGPGBase):
         # use dogtail 0.9.10 directly from git, until 0.9.10 gets packaged in
         # relevant distros; 0.9.9 have problems with handling unicode
         p = self.frontend.run(
-                'git clone -n https://gitlab.com/dogtail/dogtail && '
+                'git clone -n https://gitlab.com/dogtail/dogtail.git && '
                 'cd dogtail && '
                 'git checkout 4d7923dcda92c2c44309d2a56b0bb616a1855155',
                 passio_popen=True, passio_stderr=True)
@@ -346,9 +346,6 @@ class TC_10_Thunderbird(SplitGPGBase):
         #         != 0:
         #     self.skipTest('dogtail >= 0.9.0 testing framework not installed')
 
-        # enigmail checks for ~/.gnupg dir...
-        self.frontend.run('mkdir -p .gnupg', wait=True)
-
         p = self.frontend.run('gsettings set org.gnome.desktop.interface '
                               'toolkit-accessibility true', wait=True)
         assert p == 0, 'Failed to enable accessibility toolkit'
@@ -434,7 +431,7 @@ class TC_20_Evolution(SplitGPGBase):
         # use dogtail 0.9.10 directly from git, until 0.9.10 gets packaged in
         # relevant distros; 0.9.9 have problems with handling unicode
         p = self.frontend.run(
-                'git clone -n https://gitlab.com/dogtail/dogtail && '
+                'git clone -n https://gitlab.com/dogtail/dogtail.git && '
                 'cd dogtail && '
                 'git checkout 4d7923dcda92c2c44309d2a56b0bb616a1855155',
                 passio_popen=True, passio_stderr=True)
@@ -449,9 +446,6 @@ class TC_20_Evolution(SplitGPGBase):
         #         != 0:
         #     self.skipTest('dogtail >= 0.9.0 testing framework not installed')
 
-        # enigmail checks for ~/.gnupg dir...
-        self.frontend.run('mkdir -p .gnupg', wait=True)
-
         p = self.frontend.run('gsettings set org.gnome.desktop.interface '
                               'toolkit-accessibility true', wait=True)
         assert p == 0, 'Failed to enable accessibility toolkit'
